==> 0.0.1.tar.gz: android/src/main/java/com/example/witsystem_device_plugin/SDK/InitSDK.java <==
package com.example.witsystem_device_plugin.SDK;

import android.util.Log;

import com.example.witsystem_device_plugin.SDK.context.FlutterContext;
import com.example.witsystem_device_plugin.SDK.context.FlutterInterface;
import com.witsystem.top.witsystem_android_ble_sdk.device.WitsystmBleSDK;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleCallBack;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

public class InitSDK implements FlutterInterface<WitsystmBleSDK> {

    private FlutterContext<WitsystmBleSDK> flutterContext;

    private final String appId;

    private final String token;

    private final String appSecret;

    private final String rsaPrivateKey;

    private WitsystmBleSDK witsystmBleSDK;

    private static final String TAG = "初始化";

    private final ExecutorService executorService;

    public InitSDK(String appId, String token, String appSecret, String rsaPrivateKey) {
        this.appId = appId;
        this.token = token;
        this.appSecret = appSecret;
        this.rsaPrivateKey = rsaPrivateKey;
        executorService = Executors.newSingleThreadExecutor();
    }


    @Override
    public boolean dataHandle(FlutterContext<WitsystmBleSDK> flutterContext) {
        this.flutterContext = flutterContext;
        return true;
    }

    @Override
    public boolean execute() {
        witsystmBleSDK = WitsystmBleSDK.getInstance(flutterContext.getContext(), appId, token, appSecret, rsaPrivateKey);
        executorService.submit(() -> witsystmBleSDK.initSDK(new BleCallBack<WitsystmBleSDK>() {
            @Override
            public void success(WitsystmBleSDK witsystmBleSDK) {
                Log.i(TAG, "success: 初始化成功" + witsystmBleSDK);
                flutterContext.getResult().success(true);
            }
            @Override
            public void fail(int i, String s) {
                Log.i(TAG, "success: 初始化失败" + s);
                flutterContext.getResult().error(i + "", s, null);
            }
        }));

        return true;
    }

    @Override
    public WitsystmBleSDK result() {
        return witsystmBleSDK;
    }
}

==> 0.1.7.tar.gz: android/src/main/java/com/example/witsystem_device_plugin/SDK/InitSDK.java <==
package com.example.witsystem_device_plugin.SDK;

import android.util.Log;

import com.example.witsystem_device_plugin.SDK.context.FlutterContext;
import com.example.witsystem_device_plugin.SDK.context.FlutterInterface;
import com.witsystem.top.witsystem_android_ble_sdk.device.WitsystemSDK;
import com.witsystem.top.witsystem_android_ble_sdk.device.WitsystmBleSDK;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleCallBack;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

public class InitSDK implements FlutterInterface<WitsystemSDK> {

    private FlutterContext<WitsystemSDK> flutterContext;

    private final String appId;

    private final String token;

    private final String appSecret;

    private final String rsaPrivateKey;

    private WitsystemSDK witsystmBleSDK;

    private static final String TAG = "初始化";

    private final ExecutorService executorService;

    public InitSDK(String appId, String token, String appSecret, String rsaPrivateKey) {
        this.appId = appId;
        this.token = token;
        this.appSecret = appSecret;
        this.rsaPrivateKey = rsaPrivateKey;
        executorService = Executors.newSingleThreadExecutor();
    }


    @Override
    public boolean dataHandle(FlutterContext<WitsystemSDK> flutterContext) {
        this.flutterContext = flutterContext;
        return true;
    }

    @Override
    public boolean execute() {
        witsystmBleSDK = WitsystmBleSDK.getInstance(flutterContext.getContext(), appId, token, appSecret, rsaPrivateKey);
        executorService.submit(() -> witsystmBleSDK.initSDK(new BleCallBack<WitsystmBleSDK>() {
            @Override
            public void success(WitsystmBleSDK witsystmBleSDK) {
                Log.i(TAG, "success: 初始化成功" + witsystmBleSDK);
                flutterContext.getResult().success(true);
            }
            @Override
            public void fail(int i, String s) {
                Log.i(TAG, "success: 初始化失败" + s);
                flutterContext.getResult().error(i + "", s, null);
            }
        }));

        return true;
    }

    @Override
    public WitsystemSDK result() {
        return witsystmBleSDK;
    }
}
